@@ -1,4 +1,4 @@
-// Copyright 2018-2021 Cargill Incorporated
+// Copyright 2018-2022 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -36,6 +36,7 @@ use super::RestResourceProvider;
 use super::{Resource, RestApi};
 
 /// Builder `struct` for `RestApi`.
+#[derive(Default)]
 pub struct RestApiBuilder {
     resources: Vec<Resource>,
     bind: Option<BindConfig>,
@@ -46,20 +47,6 @@ pub struct RestApiBuilder {
     authorization_handlers: Vec<Box<dyn AuthorizationHandler>>,
 }
 
-impl Default for RestApiBuilder {
-    fn default() -> Self {
-        Self {
-            resources: Vec::new(),
-            bind: None,
-            #[cfg(feature = "rest-api-cors")]
-            whitelist: None,
-            auth_configs: Vec::new(),
-            #[cfg(feature = "authorization")]
-            authorization_handlers: Vec::new(),
-        }
-    }
-}
-
 impl RestApiBuilder {
     pub fn new() -> Self {
         Self::default()
