@@ -1,4 +1,4 @@
-// Copyright 2018-2021 Cargill Incorporated
+// Copyright 2018-2022 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 
 //! Authentication and authorization for Splinter
 
-#[cfg(feature = "rest-api-actix")]
+#[cfg(feature = "rest-api-actix-web-1")]
 pub(crate) mod actix;
 #[cfg(feature = "authorization")]
 pub mod authorization;
@@ -29,9 +29,11 @@ use super::Method;
 
 #[cfg(feature = "authorization")]
 use authorization::{AuthorizationHandler, AuthorizationHandlerResult, Permission, PermissionMap};
+#[cfg(feature = "rest-api-actix-web-1")]
 use identity::{Identity, IdentityProvider};
 
 /// The possible outcomes of attempting to authorize a client
+#[cfg(feature = "rest-api-actix-web-1")]
 enum AuthorizationResult {
     /// The client was authorized to the given identity based on the authorization header
     Authorized(Identity),
@@ -60,6 +62,7 @@ enum AuthorizationResult {
 /// * `identity_providers` - The identity providers that will be used to check the client's identity
 /// * `authorization_handlers` - The authorization handlers that will be used to check the client's
 ///   permissions
+#[cfg(feature = "rest-api-actix-web-1")]
 fn authorize(
     #[cfg(feature = "authorization")] method: &Method,
     #[cfg(any(
@@ -145,6 +148,7 @@ fn authorize(
     }
 }
 
+#[cfg(feature = "rest-api-actix-web-1")]
 fn get_identity(
     auth_header: Option<&str>,
     identity_providers: &[Box<dyn IdentityProvider>],
