@@ -1,4 +1,4 @@
-// Copyright 2018-2021 Cargill Incorporated
+// Copyright 2018-2022 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -43,8 +43,10 @@ impl SecretManager for AutoSecretManager {
 }
 
 fn generate_random_secret() -> String {
-    rand::thread_rng()
-        .sample_iter(Alphanumeric)
+    let mut rng = rand::thread_rng();
+    std::iter::repeat(())
+        .map(|()| rng.sample(Alphanumeric))
+        .map(char::from)
         .take(SECRET_LENGTH)
         .collect()
 }
